##  Example Configuration
Synchronize Relations Between Business Applications and Software Objects Parameter | Value
---|---
Source System |  SAP LeanIX
From Fact Sheet Mapping | Business Application (SAP LeanIX) - Business Application (Jira Service Management)
To Fact Sheet Mapping | Software (SAP LeanIX) - Software (Jira Service Management)
SAP LeanIX Relation | Requires
Jira Service Management Relation | Corresponding relation


